@@ -1,4 +1,5 @@
 # Import community modules.
+import os
 import json
 
 # Import custom modules.
@@ -8,19 +9,25 @@ from sloopengine import credential_conf_path
 
 # Load main.conf configuration file.
 def main_conf(path):
-  file = open(path,'r')
-  conf = file.read()
-  conf = json.loads(conf)
-  file.close()
-  return conf
+  if os.path.isfile(path) is True:
+    file = open(path,'r')
+    conf = file.read()
+    conf = json.loads(conf)
+    file.close()
+    return conf
+  else:
+    return {}
 
 # Load credential.conf configuration file.
 def credential_conf(path):
-  file = open(path,'r')
-  conf = file.read()
-  conf = json.loads(conf)
-  file.close()
-  return conf
+  if os.path.isfile(path) is True:
+    file = open(path,'r')
+    conf = file.read()
+    conf = json.loads(conf)
+    file.close()
+    return conf
+  else:
+    return {}
 
 
 # Invoke functions.
